---
title: Common
---

Common utilities used in gentropy package.

- [**Session**](session.md): Spark Session wrapper.
- [**Genomic Region**](genomic_region.md)
- [**Types**](types.md): Literal types.
- [**User Defined PySpark functions**](udf.md) User Defined Pandas functions (Pandas UDFS).
- [**Stats**](stats.md): Statistical functions.
- [**Processing**](processing.md): Common functions for gentropy dataset processing (data business logic).
- [**Spark Helpers**](spark.md): Common functions for Spark DataFrame processing (Pyspark extensions).
